%% min
% (method of [[S2FunHarmonic_index.html,S2FunHarmonic]])
%% 
% calculates the minimum of a spherical harminc or the pointwise minimum of two spherical harmonics
% 
%
%% View Code
% 
%% Syntax
%   [v,pos] = min(sF) % the position where the minimum is atained
% 
%   [v,pos] = min(sF,'numLocal',5) % the 5 largest local minima
% 
%   % with all options
%   [v,pos] = min(sF, 'startingnodes', NODES, 'lambda', LAMBDA, 'tau', TAU, 'mu', MU, 'kmax', KMAX, 'tauLS', TAULS, 'kmaxLS', KMAXLS)
% 
%   sF = min(sF, c) % minimum of a spherical functions and a constant
%   sF = min(sF1, sF2) % minimum of two spherical functions
%   sF = min(sF1, sF2, 'bandwidth', bw) % specify the new bandwidth
% 
%   % compute the minimum of a multivariate function along dim
%   sF = min(sFmulti,[],dim)
% 

%% Input
% 
% <html>
%    <table cellpadding="4" cellspacing="0" class="funcref" width="100%">
%       <tr>
%          <td width="100px">
%             <tt>sF, sF1, sF2</tt>
%          </td>
%          <td>
%                <p>[[S2Fun_index.html,S2Fun]]</p>
%          </td>
%       </tr>
%       <tr>
%          <td width="100px">
%             <tt>sFmulti</tt>
%          </td>
%          <td>
%                <p>a multivariate [[S2Fun_index.html,S2Fun]]</p>
%          </td>
%       </tr>
%       <tr>
%          <td width="100px">
%             <tt>c</tt>
%          </td>
%          <td>
%                <p>double</p>
%          </td>
%       </tr>
%       <tr>
%          <td width="100px">
%             <tt>param,val</tt>
%          </td>
%          <td>Parameters and values that control min<table cellpadding="4" cellspacing="0" class="paramval" width="100%">
%                <tr>
%                   <td class="header" width="100px">Parameter</td>
%                   <td class="header">Description</td>
%                </tr>
%                <tr>
%                   <td width="150px">
%                      <tt>'bw'</tt>
%                   </td>
%                   <td>
%                         <p>minimal degree of the spherical harmonic for pointwise minimum of two [[S2FunHarmonic_index.html,S2FunHarmonic]]</p>
%                   </td>
%                </tr>
%                <tr>
%                   <td width="150px">
%                      <tt>'STARTINGNODES'</tt>
%                   </td>
%                   <td>
%                         <pre>starting nodes of type [[vector3d_index.html,vector3d]]</pre>
%                   </td>
%                </tr>
%                <tr>
%                   <td width="150px">
%                      <tt>'LAMBDA'</tt>
%                   </td>
%                   <td>
%                         <pre>regularization parameter</pre>
%                   </td>
%                </tr>
%                <tr>
%                   <td width="150px">
%                      <tt>'TAU'</tt>
%                   </td>
%                   <td>
%                         <pre>tolerance</pre>
%                   </td>
%                </tr>
%                <tr>
%                   <td width="150px">
%                      <tt>'MU'</tt>
%                   </td>
%                   <td>
%                         <pre>in (0, 0.5) for Armijo condition</pre>
%                   </td>
%                </tr>
%                <tr>
%                   <td width="150px">
%                      <tt>'KMAX'</tt>
%                   </td>
%                   <td>
%                         <pre>maximal iterations</pre>
%                   </td>
%                </tr>
%                <tr>
%                   <td width="150px">
%                      <tt>'TAULS'</tt>
%                   </td>
%                   <td>
%                         <pre>in (0, 1) alpha(k+1) = tauLS*alpha(k)</pre>
%                   </td>
%                </tr>
%                <tr>
%                   <td width="150px">
%                      <tt>'KMAXLS'</tt>
%                   </td>
%                   <td>
%                         <pre>maximal iterations for line search</pre>
%                   </td>
%                </tr>
%             </table>
%          </td>
%       </tr>
%    </table>
% </html>
% 
%% Output
% 
% <html>
%    <table cellpadding="4" cellspacing="0" class="funcref" width="100%">
%       <tr>
%          <td width="100px">
%             <tt>v</tt>
%          </td>
%          <td>
%                <p>double</p>
%          </td>
%       </tr>
%       <tr>
%          <td width="100px">
%             <tt>pos</tt>
%          </td>
%          <td>
%                <p>[[vector3d_index.html,vector3d]]</p>
%          </td>
%       </tr>
%    </table>
% </html>
% 